@@ -1,4 +1,6 @@
 package Rubric;
+use strict;
+use warnings;
 
 =head1 NAME
 
@@ -6,13 +8,13 @@ Rubric - a notes and bookmarks manager with tagging
 
 =head1 VERSION
 
-version 0.11_02
+version 0.13_01
 
- $Id: Rubric.pm,v 1.37 2005/06/25 01:14:53 rjbs Exp $
+ $Id: /rjbs/code/rubric/trunk/lib/Rubric.pm 104 2005-11-29T05:28:52.598035Z rjbs  $
 
 =cut
 
-our $VERSION = '0.11_02';
+our $VERSION = '0.13_01';
 
 =head1 DESCRIPTION
 
@@ -49,6 +51,11 @@ L<http://rjbs.manxome.org/rubric/docs/todo>.
 
 Ricardo SIGNES, C<< <rjbs@cpan.org> >>
 
+=head1 THANKS
+
+...to a lot of people whom I will try to name, in time.  Among these helpful
+people are Ian Langworth, Shawn Sorichetti, John Cappiello, and Dave O'Neill.
+
 =head1 BUGS
 
 Please report any bugs or feature requests to C<bug-rubric@rt.cpan.org>, or
