@@ -1,4 +1,6 @@
 package Rubric::EntryTag;
+use strict;
+use warnings;
 
 =head1 NAME
 
@@ -6,7 +8,7 @@ Rubric::EntryTag - a tag on an entry
 
 =head1 VERSION
 
- $Id: EntryTag.pm,v 1.4 2005/07/02 21:42:44 rjbs Exp $
+ $Id: /rjbs/code/rubric/trunk/lib/Rubric/EntryTag.pm 85 2005-11-20T16:59:52.231131Z rjbs  $
 
 =head1 DESCRIPTION
 
