@@ -10,7 +10,7 @@ Rubric::WebApp::Login - web login processing
 
 version 0.01
 
- $Id: Login.pm,v 1.1 2004/12/20 13:24:04 rjbs Exp $
+ $Id: /rjbs/code/rubric/trunk/lib/Rubric/WebApp/Login.pm 32 2005-08-20T18:14:53.017296Z rjbs  $
 
 =cut
 
@@ -26,9 +26,22 @@ the Rubric.
 =head2 Rubric::WebApp::Login->check_for_login($webapp)
 
 This method is called by the WebApp's C<cgiapp_init>, and checks for a login
-attempt in the submitted request.  First, it checks for an HTTP login with
-C<check_for_http_login>, then for a login via POSTed parameters with
-C<check_for_post_login>.
+attempt in the submitted request.  
+
+It looks for a login username by calling C<get_login_username>, then converts
+the login name to a Rubric name by calling C<map_username> and returns
+immediately if the name can't be shown valid by calling C<valid_username>.
+
+It retrieves the User object by calling C<get_login_user> or, if needed,
+C<autocreate_user>, and returns if it can't get a User object.  It tries to
+authenticate by calling C<authenticate_login>.  If the user is authorized but
+isn't verified, he won't be logged in and the C<user_pending> parameter will be
+set on the Rubric::WebApp object.  Otherwise, he will be logged in with
+C<set_current_user>.
+
+Most of the methods above are virtual methods in this class, and should be
+implemented in subclasses.  The bundled L<Rubric::WebApp::Login::Post> (the
+default) and L<Rubric::WebApp::Login::HTTP> serve as examples.
 
 =cut
 
@@ -39,11 +52,14 @@ sub check_for_login {
 
 	$username = $self->map_username($username);
 	return unless $self->valid_username($username);
-	return unless my $user = $self->get_login_user($username);
+	return unless my $user =
+		$self->get_login_user($username) || $self->autocreate_user($username);
 	return unless $self->authenticate_login($webapp, $user);
-	$webapp->param('user_pending', 1) if $user->verification_code;
-
-	$self->set_current_user($webapp, $user);
+	if ($user->verification_code) {
+		$webapp->param('user_pending', 1);
+	} else {
+		$self->set_current_user($webapp, $user);
+	}
 }
 
 =head2 get_login_username($webapp)
@@ -89,6 +105,17 @@ sub get_login_user {
 	Rubric::User->retrieve($username);
 }
 
+=head2 autocreate_user($username)
+
+If C<get_login_user> can't find a user, this method is called to try to create
+the user automatically.  By default, it always returns nothing.  It may be
+subclassed for implementation.  (For example, one could create domain users
+from a directory.)
+
+=cut
+
+sub autocreate_user { }
+
 =head2 authenticate_login($webapp, $user)
 
 This method attempts to authenticate the user's login, checking the given
